﻿using System;
using System.Threading.Tasks;
using LuxSciWebApiWrapper;
using LuxSciWebApiWrapper.Models;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Newtonsoft.Json.Linq;

namespace LuxSciApiWrapperTest
{
    [TestClass]
    public class LuxSciApiWrapperTest
    {
        [TestMethod]
        public void GetAuthenticationTest()
        {
            AuthApiWrapper authApi = new AuthApiWrapper();
            Task<string> authCodeTask = authApi.GetAuthenticationToken();
            authCodeTask.Wait();

            Assert.IsFalse(string.IsNullOrEmpty(authCodeTask.Result));
        }

        [TestMethod]
        public void GetUserProfileTest()
        {
            UserApiWrapper userApi = new UserApiWrapper();
            Task<UserProfile> userProfileTask = userApi.GetUserProfile();
            userProfileTask.Wait();
            var userProfile = userProfileTask.Result as UserProfile;
            Assert.IsTrue(userProfile != null);
        }

        [TestMethod]
        public void SendMailTest()
        {
            UserApiWrapper userApi = new UserApiWrapper();
            EmailRequest emailRequest = new EmailRequest();

            emailRequest.Subject = "Hello, test message";
            emailRequest.Body =
                "Dear User \n This is a test message for you from LuxSci, using amazing APIs. \n Regards \n LuxSciTeam";
            emailRequest.To = new string[] { "sakthirvin@gmail.com" };
            emailRequest.FromName = "Sakthi Ramesh Kumar C";
            emailRequest.FromAddress = "admin@csharpapi.trial6.luxsci.net";
            emailRequest.BodyType = "text";
            var sendMailTask=userApi.SendMail(emailRequest);
            sendMailTask.Wait();
            Assert.IsTrue(sendMailTask.Result);
            
            
        }

        [TestMethod]
        public void SendMailWithAttachmentTest()
        {
            UserApiWrapper userApi = new UserApiWrapper();
            EmailRequest emailRequest = new EmailRequest();

            emailRequest.Subject = "Hello, test message";
            emailRequest.Body =
                "Dear User \n This is a test message for you from LuxSci, using amazing APIs. \n Regards \n LuxSciTeam";
            emailRequest.To = new string[] { "sakthirvin@gmail.com" };
            emailRequest.FromName = "Sakthi Ramesh Kumar C";
            emailRequest.FromAddress = "admin@csharpapi.trial6.luxsci.net";
            emailRequest.BodyType = "text";
            var sendMailTask = userApi.SendMailWithAttachment(emailRequest, @"D:\WorkingFolder\LuxAPI\Documents\LuxSci_API_General.pdf");
            sendMailTask.Wait();
            Assert.IsTrue(sendMailTask.Result);


        }

        [TestMethod]
        public void GetEmailSentReportTest()
        {
            UserApiWrapper userApi = new UserApiWrapper();
            Task<string> mailSentReportTask = userApi.GetMailSentReport();
            mailSentReportTask.Wait();
            var report = mailSentReportTask.Result as string;
            Assert.IsTrue(report != null);
        }

        [TestMethod]
        public void GetAccountAuthenticationTokenTest()
        {
            AuthApiWrapper authApi = new AuthApiWrapper();
            Task<string> authCodeTask = authApi.GetAccountAuthenticationToken();
            authCodeTask.Wait();

            Assert.IsFalse(string.IsNullOrEmpty(authCodeTask.Result));
        }

        [TestMethod]
        public void GetAccountProfileTest()
        {
            AccountApiWrapper accountApi = new AccountApiWrapper();
            Task<string> accountProfileTask = accountApi.GetAccountProfile ();
            accountProfileTask.Wait();
            var profile = accountProfileTask.Result as string;
            Assert.IsTrue(profile != null);
        }

        [TestMethod]
        public void CreateAliasTest()
        {
            AccountApiWrapper accountApi = new AccountApiWrapper();
            AliasRequest alias = new AliasRequest()
            {
                User = "JohnDoe",
            Action = "bounce",
            Domain = "demouser@test.trial6.luxsci.net",
            Dest = "demouser@test.trial6.luxsci.net",
            Bounce = "xxxx@gmail.com"
            };
            Task<bool> createAliasTask = accountApi.CreateAlias(alias);
            createAliasTask.Wait();
            Assert.IsTrue(createAliasTask.Result);
        }

        [TestMethod]
        public void GetAccountEmailSentReportTest()
        {
            AccountApiWrapper accountApi = new AccountApiWrapper();
            Task<string> mailSentReportTask = accountApi.GetMailSentReport( EmailType.SMTP);
            mailSentReportTask.Wait();
            var report = mailSentReportTask.Result as string;
            Assert.IsTrue(report != null);
        }

        [TestMethod]
        public void GetAccountWebEmailSentReportTest()
        {
            AccountApiWrapper accountApi = new AccountApiWrapper();
            Task<string> mailSentReportTask = accountApi.GetMailSentReport(EmailType.WebMail);
            mailSentReportTask.Wait();
            var report = mailSentReportTask.Result as string;
            Assert.IsTrue(report != null);
        }

    }
}
